/***************************************************************************
 *   Copyright (C) 2007-2012 by Tobias Schwarz                             *
 *   mail@tobias-schwarz.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#include "about.h"
#include "main.h"

aboutForm::aboutForm(kemboss *parent) : QDialog(parent)
{
   setupUi(this);
   setAttribute(Qt::WA_DeleteOnClose);

   kembossParent = parent;

   QtVersionLabel->setText("Qt version "+QString(qVersion()));

   QProcess getEmbossVersion;
   getEmbossVersion.start(parent->ksettings.embossBin()+"embossversion");
   if (!getEmbossVersion.waitForFinished(3000)) return; // waits 30 sec. for program embossversion to finish
   QByteArray embossVersion = getEmbossVersion.readAll();

   QProcess getEmbossUpdate;
   getEmbossUpdate.start(parent->ksettings.embossBin()+"embossupdate");
   if (!getEmbossUpdate.waitForFinished(3000)) return; // waits 30 sec. for program embossupdate to finish
   QByteArray embossUpdate = getEmbossUpdate.readAll();

   if (QString(embossUpdate).trimmed() == "EMBOSS "+QString(embossVersion).trimmed()+" is the latest version ("+QString(embossVersion).trimmed()+")")
      EmbossVersionLabel->setText("EMBOSS version "+QString(embossVersion)+" (Latest version)");
   else
      EmbossVersionLabel->setText("EMBOSS version "+QString(embossVersion)+" (Update available)");

   // Get latest kemboss version
   QUrl versionUrl("http://tobias-schwarz.net/programmierung/latest_kemboss_version");
   m_pVersionCtrl = new versionCheck(versionUrl, this);

   connect(m_pVersionCtrl, SIGNAL(downloaded()), SLOT(getLatestKembossVersion()));
}

void aboutForm::on_GPLButton_clicked()
{
   QString filename;
   filename = kembossParent->ksettings.kembossData()+"../copying";
   #ifdef Q_WS_WIN
   filename += ".txt";
   #endif
   #ifdef Q_WS_MAC
   filename += ".html";
   #endif
   if (QFile::exists(filename))
      QDesktopServices::openUrl(QUrl::fromLocalFile(filename));
}

void aboutForm::on_CopyrightButton_clicked()
{
   QString filename;
   filename = kembossParent->ksettings.kembossData()+"../copyright";
   #ifdef Q_WS_WIN
   filename += ".txt";
   #endif
   #ifdef Q_WS_MAC
   filename += ".html";
   #endif
   if (QFile::exists(filename))
      QDesktopServices::openUrl(QUrl::fromLocalFile(filename));
}

void aboutForm::getLatestKembossVersion()
{
   QString KVersion = m_pVersionCtrl->downloadedData();
   if (KVersion == QString(KEMBOSS_VERSION))
      KembossVersionLabel->setText("kemboss version "+QString(KEMBOSS_VERSION)+" (Latest version)");
   else
      KembossVersionLabel->setText("kemboss version "+QString(KEMBOSS_VERSION)+" (Updated version "+KVersion+" available)");
}

void aboutForm::on_URLButton_clicked()
{
   QDesktopServices::openUrl(QUrl("http://www.tobias-schwarz.net/kemboss.html"));
}

versionCheck::versionCheck(QUrl versionUrl, QObject *parent) : QObject(parent)
{
    connect(&m_WebCtrl, SIGNAL(finished(QNetworkReply*)),
                SLOT(versionDownloaded(QNetworkReply*)));
    QNetworkRequest request(versionUrl);
    m_WebCtrl.get(request);
}

versionCheck::~versionCheck()
{

}

void versionCheck::versionDownloaded(QNetworkReply* pReply)
{
    m_DownloadedData = pReply->readAll();
    //emit a signal
    emit downloaded();
}

QByteArray versionCheck::downloadedData() const
{
    return m_DownloadedData;
}
