/***************************************************************************
 *   Copyright (C) 2007-2012 by Tobias Schwarz                             *
 *   mail@tobias-schwarz.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#include <QtGui>
#include "associated_qualifiers.h"

SAQForm::SAQForm(kprogramWindow *parent, const QString fseqNumber) // Sequence associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber = fseqNumber;
   parentProgramWindow->loadFormats("sequence_formats",InputFormatComboBox);
   InputFormatComboBox->setCurrentIndex(InputFormatComboBox->findText("auto"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-sformat"+seqNumber))
          InputFormatComboBox->setCurrentIndex(
             InputFormatComboBox->findText(
                parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-sbegin"+seqNumber))
          StartSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-send"+seqNumber))
          EndSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-snucleotide"+seqNumber)
          NucleotideRadioButton->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-sprotein"+seqNumber)
          ProteinRadioButton->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-slower"+seqNumber)
          LowerCaseRadioButton->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-supper"+seqNumber)
          UpperCaseRadioButton->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-sreverse"+seqNumber)
          ReverseCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-scircular"+seqNumber)
          CircularCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-sdbname"+seqNumber))
         DatabaseNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-sid"+seqNumber))
         EntryNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-iquery"+seqNumber))
         QueryLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ioffset"+seqNumber))
          OffsetSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ufo"+seqNumber))
         UFOFeaturesLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fformat"+seqNumber))
         FeaturesFormatLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fopenfile"+seqNumber))
         FeaturesFileNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void SAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (InputFormatComboBox->currentText() != "auto")
      parentProgramWindow->associatedQualifiers.append("-sformat"+seqNumber+"="+InputFormatComboBox->currentText());
   if (StartSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-sbegin"+seqNumber+"="+StartSpinBox->text());
   if (EndSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-send"+seqNumber+"="+EndSpinBox->text());
   if (NucleotideRadioButton->isChecked())
      parentProgramWindow->associatedQualifiers.append("-snucleotide"+seqNumber);
   if (ProteinRadioButton->isChecked())
      parentProgramWindow->associatedQualifiers.append("-sprotein"+seqNumber);
   if (LowerCaseRadioButton->isChecked())
      parentProgramWindow->associatedQualifiers.append("-slower"+seqNumber);
   if (UpperCaseRadioButton->isChecked())
      parentProgramWindow->associatedQualifiers.append("-supper"+seqNumber);
   if (ReverseCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-sreverse"+seqNumber);
   if (CircularCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-scircular"+seqNumber);
   if (!DatabaseNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-sdbname"+seqNumber+"=\""+DatabaseNameLineEdit->text()+"\"");
   if (!EntryNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-sid"+seqNumber+"=\""+EntryNameLineEdit->text()+"\"");
   if (!QueryLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-iquery"+seqNumber+"=\""+QueryLineEdit->text()+"\"");
   if (OffsetSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-ioffset"+seqNumber+"="+OffsetSpinBox->text());
   if (!UFOFeaturesLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-ufo"+seqNumber+"=\""+UFOFeaturesLineEdit->text()+"\"");
   if (!FeaturesFormatLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-fformat"+seqNumber+"=\""+FeaturesFormatLineEdit->text()+"\"");
   if (!FeaturesFileNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-fopenfile"+seqNumber+"=\""+FeaturesFileNameLineEdit->text()+"\"");
   QDialog::accept();
}

AssemblyAQForm::AssemblyAQForm(kprogramWindow *parent, const QString fassemblyNumber) // Assembly associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   assemblyNumber = fassemblyNumber;

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-iformat"+assemblyNumber))
          IformatLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-cbegin"+assemblyNumber))
          StartSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-cend"+assemblyNumber))
          EndSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-idbname"+assemblyNumber))
         DatabaseNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-iquery"+assemblyNumber))
         QueryLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ioffset"+assemblyNumber))
          OffsetSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void AssemblyAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (!IformatLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-iformat"+assemblyNumber+"=\""+IformatLineEdit->text()+"\"");
   if (StartSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-cbegin"+assemblyNumber+"="+StartSpinBox->text());
   if (EndSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-cend"+assemblyNumber+"="+EndSpinBox->text());
   if (!DatabaseNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-idbname"+assemblyNumber+"=\""+DatabaseNameLineEdit->text()+"\"");
   if (!QueryLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-iquery"+assemblyNumber+"=\""+QueryLineEdit->text()+"\"");
   if (OffsetSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-ioffset"+assemblyNumber+"="+OffsetSpinBox->text());
   QDialog::accept();
}

OAQForm::OAQForm(kprogramWindow *parent, const QString num) // Outfile associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   parentProgramWindow->loadFormats("report_formats",OutfileFormatComboBox);
   OutfileFormatComboBox->setCurrentIndex(OutfileFormatComboBox->findText("default"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-rformat"+seqNumber))
          OutfileFormatComboBox->setCurrentIndex(
             OutfileFormatComboBox->findText(
                parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-raccshow"+seqNumber)
          ShowAccessionNumberCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-rdesshow"+seqNumber)
          ShowDescriptionCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-norscoreshow"+seqNumber)
          ShowScoreCheckBox->setChecked(false);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-norstrandshow"+seqNumber)
          ShowStrandCheckBox->setChecked(false);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-rusashow"+seqNumber)
          ShowFullUSACheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-rmaxall"+seqNumber))
          MaximumTotalHitsSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-rmaxseq"+seqNumber))
          MaximumHitsPerSequenceSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void OAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (OutfileFormatComboBox->currentText() != "default")
      parentProgramWindow->associatedQualifiers.append("-rformat"+seqNumber+"="+OutfileFormatComboBox->currentText());
   if (ShowAccessionNumberCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-raccshow"+seqNumber);
   if (ShowDescriptionCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-rdesshow"+seqNumber);
   if (!ShowScoreCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-norscoreshow"+seqNumber);
   if (!ShowStrandCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-norstrandshow"+seqNumber);
   if (ShowFullUSACheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-rusashow"+seqNumber);
   if (MaximumTotalHitsSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-rmaxall"+seqNumber+"="+MaximumTotalHitsSpinBox->text());
   if (MaximumHitsPerSequenceSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-rmaxseq"+seqNumber+"="+MaximumHitsPerSequenceSpinBox->text());

   QDialog::accept();
}

OsAQForm::OsAQForm(kprogramWindow *parent, const QString num) // Outseq associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   parentProgramWindow->loadFormats("report_formats",FormatComboBox);
   FormatComboBox->setCurrentIndex(FormatComboBox->findText("default"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-osformat"+seqNumber))
          FormatComboBox->setCurrentIndex(
             FormatComboBox->findText(
                parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-osdbname"+seqNumber))
         DatabaseNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-oufo"+seqNumber))
         UFOFeaturesLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-offormat"+seqNumber))
         FeaturesFormatLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ofname"+seqNumber))
         FeaturesFileNameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ossingle"+seqNumber))
         SeparateFileForEachEntryCheckBox->setChecked(true);
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void OsAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (FormatComboBox->currentText() != "default")
      parentProgramWindow->associatedQualifiers.append("-osformat"+seqNumber+"="+FormatComboBox->currentText());
   if (!DatabaseNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-osdbname"+seqNumber+"=\""+DatabaseNameLineEdit->text()+"\"");
   if (!UFOFeaturesLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-oufo="+seqNumber+"\""+UFOFeaturesLineEdit->text()+"\"");
   if (!FeaturesFormatLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-offormat"+seqNumber+"=\""+FeaturesFormatLineEdit->text()+"\"");
   if (!FeaturesFileNameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-ofname"+seqNumber+"=\""+FeaturesFileNameLineEdit->text()+"\"");
   if (SeparateFileForEachEntryCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-ossingle"+seqNumber);
   QDialog::accept();
}

OfAQForm::OfAQForm(kprogramWindow *parent, const QString num) // Outfeat associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   parentProgramWindow->loadFormats("report_formats",FormatComboBox);
   FormatComboBox->setCurrentIndex(FormatComboBox->findText("default"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-offormat"+seqNumber))
          FormatComboBox->setCurrentIndex(
             FormatComboBox->findText(
                parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-ofsingle"+seqNumber)
          SeparateFileForEachEntryCheckBox->setChecked(true);
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void OfAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (FormatComboBox->currentText() != "default")
      parentProgramWindow->associatedQualifiers.append("-offormat"+seqNumber+"="+FormatComboBox->currentText());
   if (SeparateFileForEachEntryCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-ofsingle"+seqNumber);
   QDialog::accept();
}

FAQForm::FAQForm(kprogramWindow *parent, const QString num) // Features associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   parentProgramWindow->loadFormats("report_formats",FormatComboBox);
   FormatComboBox->setCurrentIndex(FormatComboBox->findText("default"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fformat"+seqNumber))
         FormatComboBox->setCurrentIndex(
            FormatComboBox->findText(
               parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-iquery"+seqNumber))
         QueryLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-ioffset"+seqNumber))
         OffsetSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fopenfile"+seqNumber))
         FilenameLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fbegin"+seqNumber))
         StartSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-fend"+seqNumber))
         EndSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-freverse"+seqNumber)
         ReverseCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-fcircular"+seqNumber)
         CircularCheckBox->setChecked(true);
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void FAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (FormatComboBox->currentText() != "default")
      parentProgramWindow->associatedQualifiers.append("-fformat"+seqNumber+"="+FormatComboBox->currentText());
   if (!QueryLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-iquery"+seqNumber+"=\""+QueryLineEdit->text()+"\"");
   if (OffsetSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-ioffset"+seqNumber+"="+OffsetSpinBox->text());
   if (!FilenameLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-fopenfile"+seqNumber+"=\""+FilenameLineEdit->text()+"\"");
   if (StartSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-fbegin"+seqNumber+"="+StartSpinBox->text());
   if (EndSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-fend"+seqNumber+"="+EndSpinBox->text());
   if (ReverseCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-freverse"+seqNumber);
   if (CircularCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-fcircular"+seqNumber);
   QDialog::accept();
}

GAQForm::GAQForm(kprogramWindow *parent, const QString num) // Graph associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-gdesc"+seqNumber))
         DescriptionLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-gtitle"+seqNumber))
         TitleLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-gsubtitle"+seqNumber))
         SubtitleLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-gxtitle"+seqNumber))
         XAxisTitleLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-gytitle"+seqNumber))
         YAxisTitleLineEdit->setText(parentProgramWindow->associatedQualifiers.at(i).section("\"",1,1));
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void GAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (!DescriptionLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-gdesc"+seqNumber+"=\""+DescriptionLineEdit->text()+"\"");
   if (!TitleLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-gtitle"+seqNumber+"=\""+TitleLineEdit->text()+"\"");
   if (!SubtitleLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-gsubtitle"+seqNumber+"=\""+SubtitleLineEdit->text()+"\"");
   if (!XAxisTitleLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-gxtitle"+seqNumber+"=\""+XAxisTitleLineEdit->text()+"\"");
   if (!YAxisTitleLineEdit->text().isEmpty())
      parentProgramWindow->associatedQualifiers.append("-gytitle"+seqNumber+"=\""+YAxisTitleLineEdit->text()+"\"");
   QDialog::accept();
}

AAQForm::AAQForm(kprogramWindow *parent, const QString num) // Alignment associated qualifiers
{
   setupUi(this);
   parentProgramWindow = parent;
   seqNumber=num;
   parentProgramWindow->loadFormats("alignment_formats",FormatComboBox);
   FormatComboBox->setCurrentIndex(FormatComboBox->findText("default"));

   // Read parameters from parent window
   for (int i = 0; i < parentProgramWindow->associatedQualifiers.size(); ++i) {
      if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-aformat"+seqNumber))
          FormatComboBox->setCurrentIndex(
             FormatComboBox->findText(
                parentProgramWindow->associatedQualifiers.at(i).section("=",1)));
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-aaccshow"+seqNumber)
          ShowAccessionNumberCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-adesshow"+seqNumber)
          ShowDescriptionCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-ausashow"+seqNumber)
          ShowFullUSACheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i) == "-aglobal"+seqNumber)
          ShowFullSequenceCheckBox->setChecked(true);
      else if (parentProgramWindow->associatedQualifiers.at(i).startsWith("-awidth"+seqNumber))
          AlignmentWidthSpinBox->setValue(parentProgramWindow->associatedQualifiers.at(i).section("=",1).toInt());
      else otherQualifiers.append(parentProgramWindow->associatedQualifiers.at(i));
   }
}

void AAQForm::accept()
{
   parentProgramWindow->associatedQualifiers.clear();
   parentProgramWindow->associatedQualifiers += otherQualifiers;
   if (FormatComboBox->currentText() != "default")
      parentProgramWindow->associatedQualifiers.append("-aformat"+seqNumber+"="+FormatComboBox->currentText());
   if (ShowAccessionNumberCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-aaccshow"+seqNumber);
   if (ShowDescriptionCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-adesshow"+seqNumber);
   if (ShowFullUSACheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-ausashow"+seqNumber);
   if (ShowFullSequenceCheckBox->isChecked())
      parentProgramWindow->associatedQualifiers.append("-aglobal"+seqNumber);
   if (AlignmentWidthSpinBox->value() != 0)
      parentProgramWindow->associatedQualifiers.append("-awidth"+seqNumber+"="+AlignmentWidthSpinBox->text());

   QDialog::accept();
}

ACPForm::ACPForm(kprogramWindow *parent)  // Additional configuration parameters
{
   setupUi(this);
   parentProgramWindow = parent;

   // Read parameters from parent window
   QString parameters = parentProgramWindow->additionalConfigurationParameters.join("\n");
   ParameterTextEdit->setPlainText(parameters);
}

void ACPForm::accept()
{
   parentProgramWindow->additionalConfigurationParameters.clear();
   QString parameters = ParameterTextEdit->toPlainText();
   parentProgramWindow->additionalConfigurationParameters+=parameters.split("\n",QString::SkipEmptyParts);
   QDialog::accept();
}
